Module investigation

Module investigation 

Investigation reports and baseline/candidate diffing.

Functions

compare_reports
Compare a baseline and candidate investigation report.
infer_requirements
Infer operational requirements and adapter strategy from an investigation report.
infer_requirements_with_target_class
Infer operational requirements from an investigation report using explicit SLO thresholds.
investigate_har
Build an investigation report from a HAR payload.
investigate_har_with_profile
Build an investigation report from a HAR payload using an explicit analyzer profile.