pub fn plan_from_report(report: InvestigationReport) -> InvestigationBundleExpand description
Infer requirements and build a runtime policy from an existing investigation report.
pub fn plan_from_report(report: InvestigationReport) -> InvestigationBundleInfer requirements and build a runtime policy from an existing investigation report.