Investigation reports and baseline/candidate diffing.
Functions
- compare_
reports - Compare a baseline and candidate investigation report.
- infer_
requirements - Infer operational requirements and adapter strategy from an investigation report.
- infer_
requirements_ with_ target_ class - Infer operational requirements from an investigation report using explicit SLO thresholds.
- investigate_
har - Build an investigation report from a HAR payload.
- investigate_
har_ with_ profile - Build an investigation report from a HAR payload using an explicit analyzer profile.